#[repr(u32)]pub enum MetricType {
Undefined = 0,
L2 = 1,
Ip = 2,
Cosine = 3,
MipsL2 = 4,
}Expand description
Similarity metric. Search scores are always ordered from high to low; L2 is represented as negative squared distance at the API boundary.
Variants
Implementations
Sourceimpl MetricType
impl MetricType
pub fn higher_is_better(self) -> bool