pub struct SearchQuery {
pub field_name: String,
pub vector: Option<Vec<f32>>,
pub binary_vector: Option<Vec<u8>>,
pub sparse_vector: Option<Vec<(u32, f32)>>,
pub id: Option<String>,
pub topk: i32,
pub filter: Option<String>,
pub include_vector: bool,
pub include_doc_id: bool,
pub output_fields: Option<Vec<String>>,
pub fts: Option<Fts>,
pub params: Map<String, Value>,
}Expand description
A single dense, sparse, binary, id-based, or FTS query.
Fields
field_name: Stringvector: Option<Vec<f32>>binary_vector: Option<Vec<u8>>sparse_vector: Option<Vec<(u32, f32)>>id: Option<String>topk: i32filter: Option<String>include_vector: boolinclude_doc_id: booloutput_fields: Option<Vec<String>>fts: Option<Fts>params: Map<String, Value>Implementations
Sourceimpl SearchQuery
impl SearchQuery
pub fn new(field_name: &str, vector: &[f32], topk: i32) -> Result<Self>
pub fn fts(field_name: &str, fts: &Fts, topk: i32) -> Result<Self>
pub fn by_id(field_name: &str, id: &str, topk: i32) -> Result<Self>
pub fn sparse( field_name: &str, indices: &[u32], values: &[f32], topk: i32, ) -> Result<Self>
Sourcepub fn binary(field_name: &str, vector: &[u8], topk: i32) -> Result<Self>
pub fn binary(field_name: &str, vector: &[u8], topk: i32) -> Result<Self>
Creates a packed Binary32 or Binary64 exact query.
The collection schema determines the binary type and validates the byte length. Binary search uses L2 over bit coordinates, whose squared distance is the XOR Hamming count.
pub fn builder() -> SearchQueryBuilder
pub fn set_field_name(&mut self, name: &str) -> Result<()>
pub fn set_query_vector(&mut self, vector: &[f32]) -> Result<()>
pub fn set_binary_vector(&mut self, vector: &[u8]) -> Result<()>
pub fn set_sparse_vector( &mut self, indices: &[u32], values: &[f32], ) -> Result<()>
pub fn set_filter(&mut self, filter: &str) -> Result<()>
pub fn set_topk(&mut self, topk: i32) -> Result<()>
pub fn set_include_vector(&mut self, include: bool) -> Result<()>
pub fn set_include_doc_id(&mut self, include: bool) -> Result<()>
pub fn set_output_fields(&mut self, fields: &[&str]) -> Result<()>
pub fn set_hnsw_params(&mut self, params: HnswQueryParams) -> Result<()>
pub fn set_ivf_params(&mut self, params: IvfQueryParams) -> Result<()>
pub fn set_ivf_rabitq_params( &mut self, params: IvfRabitqQueryParams, ) -> Result<()>
pub fn set_flat_params(&mut self, _params: FlatQueryParams) -> Result<()>
pub fn set_diskann_params(&mut self, params: DiskannQueryParams) -> Result<()>
pub fn set_fts_params(&mut self, params: FtsQueryParams) -> Result<()>
pub fn set_fts(&mut self, fts: &Fts) -> Result<()>
pub fn set_radius(&mut self, radius: f32) -> Result<()>
pub fn get_filter(&self) -> Option<&str>
pub fn has_vector(&self) -> bool